==> ejc-probuilddiary-impl-3.0.0-20220916.071534-5-sources.jar: com/ejianc/business/probuilddiary/construct/bean/ConstructAreaDetailEntity.java <==
package com.ejianc.business.probuilddiary.construct.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工区域 详情表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_construct_area_detail")
public class ConstructAreaDetailEntity extends BaseEntity{
    private static final long serialVersionUID = 1L;
    
    @TableField(value="duty_id")
    private Long dutyId; // 责任人id
    @TableField(value="duty_name")
    private String dutyName; // 责任人名称
    @TableField(value="duty_code")
    private String dutyCode; // 责任人编码
    @TableField(value="detail_status")
    private String detailStatus; // 状态
    @TableField(value="construction_region")
    private String constructionRegion; // 施工区域
    @TableField(value = "area_id")
    private Long areaId;//区域id
    @TableField("tree_index")
    private String treeIndex;//序号
    @TableField("parent_id")
    private Long parentId;//父ID
    @TableField("detail_id")
    private Long detailId;//清单ID
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;


    public Long getDetailId() {
        return detailId;
    }

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }

    public Long getAreaId() {
        return areaId;
    }

    public void setAreaId(Long areaId) {
        this.areaId = areaId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Long getDutyId() {
        return dutyId;
    }

    public void setDutyId(Long dutyId) {
        this.dutyId = dutyId;
    }
    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }
    public String getDutyCode() {
        return dutyCode;
    }

    public void setDutyCode(String dutyCode) {
        this.dutyCode = dutyCode;
    }
    public String getDetailStatus() {
        return detailStatus;
    }

    public void setDetailStatus(String detailStatus) {
        this.detailStatus = detailStatus;
    }
    public String getConstructionRegion() {
        return constructionRegion;
    }

    public void setConstructionRegion(String constructionRegion) {
        this.constructionRegion = constructionRegion;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220920.034155-21-sources.jar: com/ejianc/business/probuilddiary/construct/bean/ConstructAreaDetailEntity.java <==
package com.ejianc.business.probuilddiary.construct.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工区域 详情表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_construct_area_detail")
public class ConstructAreaDetailEntity extends BaseEntity{
    private static final long serialVersionUID = 1L;
    
    @TableField(value="duty_id")
    private Long dutyId; // 责任人id
    @TableField(value="duty_name")
    private String dutyName; // 责任人名称
    @TableField(value="duty_code")
    private String dutyCode; // 责任人编码
    @TableField(value="detail_status")
    private String detailStatus; // 状态
    @TableField(value="construction_region")
    private String constructionRegion; // 施工区域
    @TableField(value = "area_id")
    private Long areaId;//区域id
    @TableField("tree_index")
    private String treeIndex;//序号
    @TableField("parent_id")
    private Long parentId;//父ID
    @TableField("detail_id")
    private Long detailId;//清单ID
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;
    @TableField(value = "detail_bill_state")
    private String detailBillState;//单据状态

    public String getDetailBillState() {
        return detailBillState;
    }

    public void setDetailBillState(String detailBillState) {
        this.detailBillState = detailBillState;
    }

    public Long getDetailId() {
        return detailId;
    }

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }

    public Long getAreaId() {
        return areaId;
    }

    public void setAreaId(Long areaId) {
        this.areaId = areaId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Long getDutyId() {
        return dutyId;
    }

    public void setDutyId(Long dutyId) {
        this.dutyId = dutyId;
    }
    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }
    public String getDutyCode() {
        return dutyCode;
    }

    public void setDutyCode(String dutyCode) {
        this.dutyCode = dutyCode;
    }
    public String getDetailStatus() {
        return detailStatus;
    }

    public void setDetailStatus(String detailStatus) {
        this.detailStatus = detailStatus;
    }
    public String getConstructionRegion() {
        return constructionRegion;
    }

    public void setConstructionRegion(String constructionRegion) {
        this.constructionRegion = constructionRegion;
    }
    
}
